﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.Data;
using Infragistics.Controls;
using Infragistics.Controls.Charts;
using System.Diagnostics;
using System.Windows.Controls.Primitives;
using System.ComponentModel;

namespace DynamicallyGeneratedSeries
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            DataContext = new GraphViewModel();

        }

        private void XamDataChartContainer1_Loaded(object sender, RoutedEventArgs e)
        {
            GraphConfig data = (sender as XamDock).DataContext as GraphConfig;

            Legend legend = new Legend();
            XamDock.SetEdge(legend, DockEdge.InsideTop);
            XamDock.SetVerticalDockAlignment(legend, System.Windows.VerticalAlignment.Top);
            XamDock.SetHorizontalDockAlignment(legend, System.Windows.HorizontalAlignment.Right);

            XamDataChart chart = new XamDataChart
            {
                Height = 200,
                CrosshairVisibility = System.Windows.Visibility.Visible,
                PlotAreaBorderBrush = Brushes.Black,
                PlotAreaBackground = Brushes.Black,
                BorderThickness = new Thickness(0),
                PlotAreaBorderThickness = new Thickness(0),
                Legend = legend, 
                DataContext = data
            };

            NumericXAxis xAxis = new NumericXAxis();
            xAxis.SetBinding(NumericXAxis.MinimumValueProperty, new Binding("MinDateTime.Ticks"));
            xAxis.SetBinding(NumericXAxis.MaximumValueProperty, new Binding("MaxDateTime.Ticks"));
            xAxis.LabelSettings = new AxisLabelSettings { Location = AxisLabelsLocation.OutsideBottom, Visibility = System.Windows.Visibility.Collapsed };

            chart.Axes.Add(xAxis);

            NumericYAxis yAxis = new NumericYAxis();
            yAxis.Label = LayoutRoot.Resources["LabelDataTemplate"] as DataTemplate;
            chart.Axes.Add(yAxis);

           
            ScatterLineSeries series1 = new ScatterLineSeries
            {
                Title = "Series 1",
                MarkerType = MarkerType.None,
                XMemberPath = "Date", 
                XAxis = xAxis,
                YAxis = yAxis,
                YMemberPath = "Value1",
            };
            series1.SetBinding(ScatterLineSeries.ItemsSourceProperty,
                new Binding("GraphData"));

            chart.Series.Add(series1);

            ScatterLineSeries series2 = new ScatterLineSeries
            {
                Title = "Series 2",
                MarkerType = MarkerType.None,
                XMemberPath = "Date",
                XAxis = xAxis,
                YAxis = yAxis,
                YMemberPath = "Value2",
            };
            series2.SetBinding(ScatterLineSeries.ItemsSourceProperty,
                new Binding("GraphData"));

            chart.Series.Add(series2);

            ScatterLineSeries series3 = new ScatterLineSeries
            {
                Title = "Series 3",
                MarkerType = MarkerType.None,
                XMemberPath = "Date",
                XAxis = xAxis,
                YAxis = yAxis,
                YMemberPath = "Value3",
            };
            series3.SetBinding(ScatterLineSeries.ItemsSourceProperty,
                new Binding("GraphData"));

            chart.Series.Add(series3);
            

            (sender as XamDock).Children.Add(chart);
            (sender as XamDock).Children.Add(legend);
        }

    }

    public class GraphViewModel
    {
        public GraphViewModel()
        {
            Graphs = new ObservableCollection<GraphConfig>();

            for (int i = 0; i < 10; i++)
            {
                Graphs.Add(new GraphConfig());
            }
        }

        public ObservableCollection<GraphConfig> Graphs { get; set; }

    }

    public class GraphConfig 
    {
        public GraphConfig()
        {
            Random r = new Random();
            int rows = 1000;
            GraphData = ChartData.GenerateData(rows);

            MinDateTime = DateTime.Now;
            MaxDateTime = DateTime.Now.AddDays(rows);
        }

        public DateTime MinDateTime { get; set; }
        public DateTime MaxDateTime { get; set; }

        public ObservableCollection<ChartData> GraphData { get; set; }
    }

    public class LabelVisibilityConverter : IMultiValueConverter
    {

        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            double min = (double)values[0];
            double max = (double)values[1];
            double val = (double)values[2];

            if (min == val || max == val)
                return Visibility.Collapsed;
            else
                return Visibility.Visible;
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class ChartData
    {
        public DateTime Date { get; set; }
        public double Value1 { get; set; }
        public double Value2 { get; set; }
        public double Value3 { get; set; }

        public static ObservableCollection<ChartData> GenerateData(int count)
        {
            ObservableCollection<ChartData> data = new ObservableCollection<ChartData>();

            Random r = new Random();

            ChartData data0 = new ChartData
            {
                Date = DateTime.Now,
                Value1 = r.Next(20, 40),
                Value2 = r.Next(20, 40),
                Value3 = r.Next(20, 40),
            };

            data.Add(data0);

            for (int i = 1; i < count; i++)
            {
                ChartData dat = new ChartData
                {
                    Date = DateTime.Now.AddDays(i),
                };

                if (r.NextDouble() > .5)
                {
                    dat.Value1 = data[i - 1].Value1 + r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 + r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 + r.NextDouble();
                }
                else
                {
                    dat.Value1 = data[i - 1].Value1 - r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 - r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 - r.NextDouble();
                }

                data.Add(dat);
            }

            return data;
        }
    }
}
